==> mkdocs-material-4.5.1.tar.gz: mkdocs-material-4.5.1/README.md <==
[![Travis][travis-image]][travis-link]
[![Downloads][downloads-image]][downloads-link]
[![Gitter][gitter-image]][gitter-link]
[![PyPI][pypi-image]][pypi-link]
[![dependabot][dependabot-image]][dependabot-link]

  [travis-image]: https://travis-ci.org/squidfunk/mkdocs-material.svg?branch=master
  [travis-link]: https://travis-ci.org/squidfunk/mkdocs-material
  [downloads-image]: https://img.shields.io/pypi/dm/mkdocs-material.svg
  [downloads-link]: https://pypistats.org/packages/mkdocs-material
  [gitter-image]: https://badges.gitter.im/squidfunk/mkdocs-material.svg
  [gitter-link]: https://gitter.im/squidfunk/mkdocs-material
  [pypi-image]: https://img.shields.io/pypi/v/mkdocs-material.svg
  [pypi-link]: https://pypi.python.org/pypi/mkdocs-material
  [dependabot-image]: https://img.shields.io/badge/dependabot-enabled-06f.svg
  [dependabot-link]: https://dependabot.com

# Material for MkDocs

A Material Design theme for [MkDocs][1].

[![Material for MkDocs](https://raw.githubusercontent.com/squidfunk/mkdocs-material/master/docs/assets/images/material.png)][2]

  [1]: https://www.mkdocs.org
  [2]: https://squidfunk.github.io/mkdocs-material/

## Quick start

Install the latest version of Material with `pip`:

``` sh
pip install mkdocs-material
```

Append the following line to your project's `mkdocs.yml`:

``` yaml
theme:
  name: 'material'
```

## What to expect

* Responsive design and fluid layout for all kinds of screens and devices,
  designed to serve your project documentation in a user-friendly way in 40
  languages with optimal readability.

* Easily customizable primary and accent color, fonts, favicon and logo;
  straight forward localization through theme extension; integrated with Google
  Analytics, Disqus and GitHub.

* Well-designed search interface accessible through hotkeys (<kbd>F</kbd> or
  <kbd>S</kbd>), intelligent grouping of search results, search term
  highlighting and lazy loading.

For detailed installation instructions and a demo, visit
https://squidfunk.github.io/mkdocs-material/

## License

**MIT License**

Copyright (c) 2016-2019 Martin Donath

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.

==> mkdocs-material-4.6.0.tar.gz: mkdocs-material-4.6.0/README.md <==
[![Github Action][action-image]][action-link]
[![Downloads][downloads-image]][downloads-link]
[![Gitter][gitter-image]][gitter-link]
[![PyPI][pypi-image]][pypi-link]
[![dependabot][dependabot-image]][dependabot-link]

  [action-image]: https://github.com/squidfunk/mkdocs-material/workflows/ci/badge.svg?branch=master
  [action-link]: https://github.com/squidfunk/mkdocs-material/actions
  [downloads-image]: https://img.shields.io/pypi/dm/mkdocs-material.svg
  [downloads-link]: https://pypistats.org/packages/mkdocs-material
  [gitter-image]: https://badges.gitter.im/squidfunk/mkdocs-material.svg
  [gitter-link]: https://gitter.im/squidfunk/mkdocs-material
  [pypi-image]: https://img.shields.io/pypi/v/mkdocs-material.svg
  [pypi-link]: https://pypi.python.org/pypi/mkdocs-material
  [dependabot-image]: https://img.shields.io/badge/dependabot-enabled-06f.svg
  [dependabot-link]: https://dependabot.com

# Material for MkDocs

A Material Design theme for [MkDocs][1].

[![Material for MkDocs](https://raw.githubusercontent.com/squidfunk/mkdocs-material/master/docs/assets/images/material.png)][2]

  [1]: https://www.mkdocs.org
  [2]: https://squidfunk.github.io/mkdocs-material/

## Quick start

Install the latest version of Material with `pip`:

``` sh
pip install mkdocs-material
```

Append the following line to your project's `mkdocs.yml`:

``` yaml
theme:
  name: 'material'
```

## What to expect

* Responsive design and fluid layout for all kinds of screens and devices,
  designed to serve your project documentation in a user-friendly way in 40
  languages with optimal readability.

* Easily customizable primary and accent color, fonts, favicon and logo;
  straight forward localization through theme extension; integrated with Google
  Analytics, Disqus and GitHub.

* Well-designed search interface accessible through hotkeys (<kbd>F</kbd> or
  <kbd>S</kbd>), intelligent grouping of search results, search term
  highlighting and lazy loading.

For detailed installation instructions and a demo, visit
https://squidfunk.github.io/mkdocs-material/

## Support

If you're happy with Material for MkDocs and feel like giving something back,
you may check out squidfunk's [Amazon wish list][3].

  [3]: https://amzn.to/353WRpj

## License

**MIT License**

Copyright (c) 2016-2019 Martin Donath

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to
deal in the Software without restriction, including without limitation the
rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
sell copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
IN THE SOFTWARE.
